API reference
=============

datetime utilities
------------------

.. automodule:: seveno_pyutil.datetime_utilities
   :members:
   :undoc-members:
   :show-inheritance:

benchmarking utilities
----------------------

.. automodule:: seveno_pyutil.benchmarking_utilities
   :members:
   :undoc-members:
   :show-inheritance:


file utilities
--------------

.. automodule:: seveno_pyutil.file_utilities
   :members:
   :undoc-members:
   :show-inheritance:

logging utilities
-----------------

.. automodule:: seveno_pyutil.logging_utilities
   :members: StandardMetadataFilter, silence_logger, SQLFilter, log_to_console_for, log_to_tmp_file_for, SingleLineFormatter, SingleLineColoredFormatter

metaprogramming helpers
-----------------------

.. automodule:: seveno_pyutil.metaprogramming_helpers
   :members:
   :undoc-members:
   :show-inheritance:

os utilities
------------

.. automodule:: seveno_pyutil.os_utilities
   :members:
   :undoc-members:
   :show-inheritance:

string utilities
----------------

.. automodule:: seveno_pyutil.string_utilities
   :members:
   :undoc-members:

collections utilities
---------------------

.. automodule:: seveno_pyutil.collections_utilities
   :members:
   :undoc-members:
   :show-inheritance:

error utilities
---------------

.. automodule:: seveno_pyutil.error_utilities
   :members:
   :undoc-members:
   :show-inheritance:
